<?php
/**
* JoomBlog component for Joomla 1.6 & 1.7
* @package JoomBlog
* @author JoomPlace Team
* @Copyright Copyright (C) JoomPlace, www.joomplace.com
* @license GNU/GPL http://www.gnu.org/copyleft/gpl.html
*/

// no direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

/**
 * JoomBlog Search plugin
 *
 */
class plgSearchJoomblog extends JPlugin
{
	public function __construct(& $subject, $config)
	{
		parent::__construct($subject, $config);
		$this->loadLanguage();
	}

	function onContentSearchAreas() {
		static $areas = array(
			'joomblog' => 'PLG_SEARCH_JOOMBLOG_BLOG'
			);
			return $areas;
	}

	function onContentSearch($text, $phrase='', $ordering='', $areas=null)
	{
		$db		= JFactory::getDbo();
		$app	= JFactory::getApplication();
		$user	= JFactory::getUser();
		$groups	= implode(',', $user->getAuthorisedViewLevels());
		$tag = JFactory::getLanguage()->getTag();

		$searchText = $text;
		if (is_array($areas)) {
			if (!array_intersect($areas, array_keys($this->onContentSearchAreas()))) {
				return array();
			}
		}

		$limit	= $this->params->def('search_limit',		50);

		$nullDate		= $db->getNullDate();
		$date = JFactory::getDate();
		$now = $date->toMySQL();

		$text = trim($text);
		if ($text == '') {
			return array();
		}

		$wheres = array();
		switch ($phrase) {
			case 'exact':
				$text		= $db->Quote('%'.$db->getEscaped($text, true).'%', false);
				$wheres2	= array();
				$wheres2[]	= 'a.title LIKE '.$text;
				$wheres2[]	= 'a.introtext LIKE '.$text;
				$wheres2[]	= 'a.fulltext LIKE '.$text;
				$wheres2[]	= 'a.metakey LIKE '.$text;
				$wheres2[]	= 'a.metadesc LIKE '.$text;
				$where		= '(' . implode(') OR (', $wheres2) . ')';
				break;

			case 'all':
			case 'any':
			default:
				$words = explode(' ', $text);
				$wheres = array();
				foreach ($words as $word) {
					$word		= $db->Quote('%'.$db->getEscaped($word, true).'%', false);
					$wheres2	= array();
					$wheres2[]	= 'a.title LIKE '.$word;
					$wheres2[]	= 'a.introtext LIKE '.$word;
					$wheres2[]	= 'a.fulltext LIKE '.$word;
					$wheres2[]	= 'a.metakey LIKE '.$word;
					$wheres2[]	= 'a.metadesc LIKE '.$word;
					$wheres[]	= implode(' OR ', $wheres2);
				}
				$where = '(' . implode(($phrase == 'all' ? ') AND (' : ') OR ('), $wheres) . ')';
				break;
		}

		$morder = '';
		switch ($ordering) {
			case 'oldest':
				$order = 'a.created ASC';
				break;

			case 'popular':
				$order = 'a.hits DESC';
				break;

			case 'alpha':
				$order = 'a.title ASC';
				break;

			case 'category':
				$order = 'c.title ASC, a.title ASC';
				$morder = 'a.title ASC';
				break;

			case 'newest':
			default:
				$order = 'a.created DESC';
				break;
		}

		$rows = array();
		$query	= $db->getQuery(true);

		// search articles
		if ($limit > 0)
		{
			$query->clear();
			$query->select('a.id, a.title AS title, a.metadesc, a.metakey, a.created AS created, p.posts, a.created_by, '
						.'CONCAT(a.introtext, a.fulltext) AS text, c.title AS section, '
						.'CASE WHEN CHAR_LENGTH(a.alias) THEN CONCAT_WS(":", a.id, a.alias) ELSE a.id END as slug, '
						.'CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(":", c.id, c.alias) ELSE c.id END as catslug, '
						.'"2" AS browsernav');
			$query->from('#__content AS a');
			$query->innerJoin('#__categories AS c ON c.id=a.catid');
			$query->leftJoin(" `#__joomblog_privacy` AS `p` ON `p`.`postid`=`a`.`id` AND `p`.`isblog`=0 ");
			$query->where('('. $where .')' . 'AND a.state=1 AND c.published = 1 AND a.access IN ('.$groups.') '
						.'AND c.access IN ('.$groups.') '
						.'AND c.extension="com_joomblog" '
						.'AND (a.publish_up = '.$db->Quote($nullDate).' OR a.publish_up <= '.$db->Quote($now).') '
						.'AND (a.publish_down = '.$db->Quote($nullDate).' OR a.publish_down >= '.$db->Quote($now).')' );
			$query->group('a.id');
			$query->order($order);

			// Filter by language
			if ($app->isSite() && $app->getLanguageFilter()) {
				$query->where('a.language in (' . $db->Quote($tag) . ',' . $db->Quote('*') . ')');
				$query->where('c.language in (' . $db->Quote($tag) . ',' . $db->Quote('*') . ')');
			}
			$db->setQuery($query, 0, $limit);
			$list = $db->loadObjectList();
			$limit -= count($list);
			$query	= $db->getQuery(true);
			$query->select('`id`');
			$query->from('#__menu');
			$query->where('`link`="index.php?option=com_joomblog&view=blogger"');
			$db->setQuery($query, 0, 1);
			$Itemid = $db->loadResult();
			$itemid = ($Itemid?$Itemid:JRequest::getInt('Itemid'));
			if (isset($list))
			{
				foreach($list as $key => $item)
				{
					$list[$key]->href = JRoute::_('index.php?option=com_joomblog&show='.$item->id.'&Itemid='.$itemid);
				}
			}
			$rows[] = $list;
		}
		$results = array();
		
		if (count($rows))
		{
			foreach($rows as $row)
			{
				$new_row = array();
						
				
				foreach($row AS $key => $article) {
					
					switch ( $article->posts ) 
					{
						case 0: break;
						case 1:	
							if (!$user->id) 
							{
								unset($article);
								continue;
							}
						break;
						case 2:	
							if (!$user->id) 
							{
								unset($article);
								continue;
							}else
							{
								if (!$this->isFriends($article->id) && $user->id!=$article->created_by)
								{
									unset($article);
									continue;
								} 
							}
						break;
						case 3:	
							if (!$user->id) 
							{
								unset($article);
								continue;
							}else
							{
								if ($user->id!=$article->created_by)
								{
									unset($article);
									continue;
								}
							}						
						break;
				}
					
					if (isset($article))
					if (searchHelper::checkNoHTML($article, $searchText, array('text', 'title', 'metadesc', 'metakey'))) {
						$new_row[] = $article;
					}
				}
				$results = array_merge($results, (array) $new_row);
			}
		}
		return $results;
	}
	
	protected function isFriends($id=0)
	{
		if (!$id) return false;
		$db	=& JFactory::getDBO();
		$user =& JFactory::getUser();
		$id1=$user->id;
		
		$db->setQuery(" SELECT `user_id`  FROM `#__joomblog_list_blogs` WHERE id=".$id);
		$id2=$db->loadResult();
		if ($id1 && $id2)
		{
		$db->setQuery(	" SELECT `connection_id` FROM `#__community_connection` " .
						" WHERE connect_from=".(int)$id1." AND connect_to=".(int)$id2." AND `status`=1 ");
		$frindic = $db->loadResult();
		
		if ($frindic) return true; else return false;
		}
		return false;				
	}
}
